==> zio-aws-sagemaker_2.12-5.17.157.2-sources.jar: zio/aws/sagemaker/model/DescribeModelBiasJobDefinitionResponse.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import zio.aws.sagemaker.model.primitives.{
  RoleArn,
  Timestamp,
  MonitoringJobDefinitionName,
  MonitoringJobDefinitionArn
}
import scala.jdk.CollectionConverters._
final case class DescribeModelBiasJobDefinitionResponse(
    jobDefinitionArn: MonitoringJobDefinitionArn,
    jobDefinitionName: MonitoringJobDefinitionName,
    creationTime: Timestamp,
    modelBiasBaselineConfig: Option[
      zio.aws.sagemaker.model.ModelBiasBaselineConfig
    ] = None,
    modelBiasAppSpecification: zio.aws.sagemaker.model.ModelBiasAppSpecification,
    modelBiasJobInput: zio.aws.sagemaker.model.ModelBiasJobInput,
    modelBiasJobOutputConfig: zio.aws.sagemaker.model.MonitoringOutputConfig,
    jobResources: zio.aws.sagemaker.model.MonitoringResources,
    networkConfig: Option[zio.aws.sagemaker.model.MonitoringNetworkConfig] =
      None,
    roleArn: RoleArn,
    stoppingCondition: Option[
      zio.aws.sagemaker.model.MonitoringStoppingCondition
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.DescribeModelBiasJobDefinitionResponse = {
    import DescribeModelBiasJobDefinitionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.DescribeModelBiasJobDefinitionResponse
      .builder()
      .jobDefinitionArn(
        MonitoringJobDefinitionArn.unwrap(jobDefinitionArn): java.lang.String
      )
      .jobDefinitionName(
        MonitoringJobDefinitionName.unwrap(jobDefinitionName): java.lang.String
      )
      .creationTime(Timestamp.unwrap(creationTime): Instant)
      .optionallyWith(
        modelBiasBaselineConfig.map(value => value.buildAwsValue())
      )(_.modelBiasBaselineConfig)
      .modelBiasAppSpecification(modelBiasAppSpecification.buildAwsValue())
      .modelBiasJobInput(modelBiasJobInput.buildAwsValue())
      .modelBiasJobOutputConfig(modelBiasJobOutputConfig.buildAwsValue())
      .jobResources(jobResources.buildAwsValue())
      .optionallyWith(networkConfig.map(value => value.buildAwsValue()))(
        _.networkConfig
      )
      .roleArn(RoleArn.unwrap(roleArn): java.lang.String)
      .optionallyWith(stoppingCondition.map(value => value.buildAwsValue()))(
        _.stoppingCondition
      )
      .build()
  }
  def asReadOnly
      : zio.aws.sagemaker.model.DescribeModelBiasJobDefinitionResponse.ReadOnly =
    zio.aws.sagemaker.model.DescribeModelBiasJobDefinitionResponse
      .wrap(buildAwsValue())
}
object DescribeModelBiasJobDefinitionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.DescribeModelBiasJobDefinitionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.sagemaker.model.DescribeModelBiasJobDefinitionResponse =
      zio.aws.sagemaker.model.DescribeModelBiasJobDefinitionResponse(
        jobDefinitionArn,
        jobDefinitionName,
        creationTime,
        modelBiasBaselineConfig.map(value => value.asEditable),
        modelBiasAppSpecification.asEditable,
        modelBiasJobInput.asEditable,
        modelBiasJobOutputConfig.asEditable,
        jobResources.asEditable,
        networkConfig.map(value => value.asEditable),
        roleArn,
        stoppingCondition.map(value => value.asEditable)
      )
    def jobDefinitionArn: MonitoringJobDefinitionArn
    def jobDefinitionName: MonitoringJobDefinitionName
    def creationTime: Timestamp
    def modelBiasBaselineConfig
        : Option[zio.aws.sagemaker.model.ModelBiasBaselineConfig.ReadOnly]
    def modelBiasAppSpecification
        : zio.aws.sagemaker.model.ModelBiasAppSpecification.ReadOnly
    def modelBiasJobInput: zio.aws.sagemaker.model.ModelBiasJobInput.ReadOnly
    def modelBiasJobOutputConfig
        : zio.aws.sagemaker.model.MonitoringOutputConfig.ReadOnly
    def jobResources: zio.aws.sagemaker.model.MonitoringResources.ReadOnly
    def networkConfig
        : Option[zio.aws.sagemaker.model.MonitoringNetworkConfig.ReadOnly]
    def roleArn: RoleArn
    def stoppingCondition
        : Option[zio.aws.sagemaker.model.MonitoringStoppingCondition.ReadOnly]
    def getJobDefinitionArn: ZIO[Any, Nothing, MonitoringJobDefinitionArn] =
      ZIO.succeed(jobDefinitionArn)
    def getJobDefinitionName: ZIO[Any, Nothing, MonitoringJobDefinitionName] =
      ZIO.succeed(jobDefinitionName)
    def getCreationTime: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(creationTime)
    def getModelBiasBaselineConfig: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.ModelBiasBaselineConfig.ReadOnly
    ] = AwsError.unwrapOptionField(
      "modelBiasBaselineConfig",
      modelBiasBaselineConfig
    )
    def getModelBiasAppSpecification: ZIO[
      Any,
      Nothing,
      zio.aws.sagemaker.model.ModelBiasAppSpecification.ReadOnly
    ] = ZIO.succeed(modelBiasAppSpecification)
    def getModelBiasJobInput: ZIO[
      Any,
      Nothing,
      zio.aws.sagemaker.model.ModelBiasJobInput.ReadOnly
    ] = ZIO.succeed(modelBiasJobInput)
    def getModelBiasJobOutputConfig: ZIO[
      Any,
      Nothing,
      zio.aws.sagemaker.model.MonitoringOutputConfig.ReadOnly
    ] = ZIO.succeed(modelBiasJobOutputConfig)
    def getJobResources: ZIO[
      Any,
      Nothing,
      zio.aws.sagemaker.model.MonitoringResources.ReadOnly
    ] = ZIO.succeed(jobResources)
    def getNetworkConfig: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.MonitoringNetworkConfig.ReadOnly
    ] = AwsError.unwrapOptionField("networkConfig", networkConfig)
    def getRoleArn: ZIO[Any, Nothing, RoleArn] = ZIO.succeed(roleArn)
    def getStoppingCondition: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.MonitoringStoppingCondition.ReadOnly
    ] = AwsError.unwrapOptionField("stoppingCondition", stoppingCondition)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.DescribeModelBiasJobDefinitionResponse
  ) extends zio.aws.sagemaker.model.DescribeModelBiasJobDefinitionResponse.ReadOnly {
    override val jobDefinitionArn: MonitoringJobDefinitionArn =
      zio.aws.sagemaker.model.primitives
        .MonitoringJobDefinitionArn(impl.jobDefinitionArn())
    override val jobDefinitionName: MonitoringJobDefinitionName =
      zio.aws.sagemaker.model.primitives
        .MonitoringJobDefinitionName(impl.jobDefinitionName())
    override val creationTime: Timestamp =
      zio.aws.sagemaker.model.primitives.Timestamp(impl.creationTime())
    override val modelBiasBaselineConfig
        : Option[zio.aws.sagemaker.model.ModelBiasBaselineConfig.ReadOnly] =
      scala
        .Option(impl.modelBiasBaselineConfig())
        .map(value =>
          zio.aws.sagemaker.model.ModelBiasBaselineConfig.wrap(value)
        )
    override val modelBiasAppSpecification
        : zio.aws.sagemaker.model.ModelBiasAppSpecification.ReadOnly =
      zio.aws.sagemaker.model.ModelBiasAppSpecification
        .wrap(impl.modelBiasAppSpecification())
    override val modelBiasJobInput
        : zio.aws.sagemaker.model.ModelBiasJobInput.ReadOnly =
      zio.aws.sagemaker.model.ModelBiasJobInput.wrap(impl.modelBiasJobInput())
    override val modelBiasJobOutputConfig
        : zio.aws.sagemaker.model.MonitoringOutputConfig.ReadOnly =
      zio.aws.sagemaker.model.MonitoringOutputConfig
        .wrap(impl.modelBiasJobOutputConfig())
    override val jobResources
        : zio.aws.sagemaker.model.MonitoringResources.ReadOnly =
      zio.aws.sagemaker.model.MonitoringResources.wrap(impl.jobResources())
    override val networkConfig
        : Option[zio.aws.sagemaker.model.MonitoringNetworkConfig.ReadOnly] =
      scala
        .Option(impl.networkConfig())
        .map(value =>
          zio.aws.sagemaker.model.MonitoringNetworkConfig.wrap(value)
        )
    override val roleArn: RoleArn =
      zio.aws.sagemaker.model.primitives.RoleArn(impl.roleArn())
    override val stoppingCondition
        : Option[zio.aws.sagemaker.model.MonitoringStoppingCondition.ReadOnly] =
      scala
        .Option(impl.stoppingCondition())
        .map(value =>
          zio.aws.sagemaker.model.MonitoringStoppingCondition.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.DescribeModelBiasJobDefinitionResponse
  ): zio.aws.sagemaker.model.DescribeModelBiasJobDefinitionResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-sagemaker_2.13-5.17.164.1-sources.jar: zio/aws/sagemaker/model/DescribeModelBiasJobDefinitionResponse.scala <==
package zio.aws.sagemaker.model
import zio.aws.sagemaker.model.primitives.{
  RoleArn,
  Timestamp,
  MonitoringJobDefinitionName,
  MonitoringJobDefinitionArn
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class DescribeModelBiasJobDefinitionResponse(
    jobDefinitionArn: MonitoringJobDefinitionArn,
    jobDefinitionName: MonitoringJobDefinitionName,
    creationTime: Timestamp,
    modelBiasBaselineConfig: Optional[
      zio.aws.sagemaker.model.ModelBiasBaselineConfig
    ] = Optional.Absent,
    modelBiasAppSpecification: zio.aws.sagemaker.model.ModelBiasAppSpecification,
    modelBiasJobInput: zio.aws.sagemaker.model.ModelBiasJobInput,
    modelBiasJobOutputConfig: zio.aws.sagemaker.model.MonitoringOutputConfig,
    jobResources: zio.aws.sagemaker.model.MonitoringResources,
    networkConfig: Optional[zio.aws.sagemaker.model.MonitoringNetworkConfig] =
      Optional.Absent,
    roleArn: RoleArn,
    stoppingCondition: Optional[
      zio.aws.sagemaker.model.MonitoringStoppingCondition
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.DescribeModelBiasJobDefinitionResponse = {
    import DescribeModelBiasJobDefinitionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.DescribeModelBiasJobDefinitionResponse
      .builder()
      .jobDefinitionArn(
        MonitoringJobDefinitionArn.unwrap(jobDefinitionArn): java.lang.String
      )
      .jobDefinitionName(
        MonitoringJobDefinitionName.unwrap(jobDefinitionName): java.lang.String
      )
      .creationTime(Timestamp.unwrap(creationTime): Instant)
      .optionallyWith(
        modelBiasBaselineConfig.map(value => value.buildAwsValue())
      )(_.modelBiasBaselineConfig)
      .modelBiasAppSpecification(modelBiasAppSpecification.buildAwsValue())
      .modelBiasJobInput(modelBiasJobInput.buildAwsValue())
      .modelBiasJobOutputConfig(modelBiasJobOutputConfig.buildAwsValue())
      .jobResources(jobResources.buildAwsValue())
      .optionallyWith(networkConfig.map(value => value.buildAwsValue()))(
        _.networkConfig
      )
      .roleArn(RoleArn.unwrap(roleArn): java.lang.String)
      .optionallyWith(stoppingCondition.map(value => value.buildAwsValue()))(
        _.stoppingCondition
      )
      .build()
  }
  def asReadOnly
      : zio.aws.sagemaker.model.DescribeModelBiasJobDefinitionResponse.ReadOnly =
    zio.aws.sagemaker.model.DescribeModelBiasJobDefinitionResponse
      .wrap(buildAwsValue())
}
object DescribeModelBiasJobDefinitionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.DescribeModelBiasJobDefinitionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.sagemaker.model.DescribeModelBiasJobDefinitionResponse =
      zio.aws.sagemaker.model.DescribeModelBiasJobDefinitionResponse(
        jobDefinitionArn,
        jobDefinitionName,
        creationTime,
        modelBiasBaselineConfig.map(value => value.asEditable),
        modelBiasAppSpecification.asEditable,
        modelBiasJobInput.asEditable,
        modelBiasJobOutputConfig.asEditable,
        jobResources.asEditable,
        networkConfig.map(value => value.asEditable),
        roleArn,
        stoppingCondition.map(value => value.asEditable)
      )
    def jobDefinitionArn: MonitoringJobDefinitionArn
    def jobDefinitionName: MonitoringJobDefinitionName
    def creationTime: Timestamp
    def modelBiasBaselineConfig
        : Optional[zio.aws.sagemaker.model.ModelBiasBaselineConfig.ReadOnly]
    def modelBiasAppSpecification
        : zio.aws.sagemaker.model.ModelBiasAppSpecification.ReadOnly
    def modelBiasJobInput: zio.aws.sagemaker.model.ModelBiasJobInput.ReadOnly
    def modelBiasJobOutputConfig
        : zio.aws.sagemaker.model.MonitoringOutputConfig.ReadOnly
    def jobResources: zio.aws.sagemaker.model.MonitoringResources.ReadOnly
    def networkConfig
        : Optional[zio.aws.sagemaker.model.MonitoringNetworkConfig.ReadOnly]
    def roleArn: RoleArn
    def stoppingCondition
        : Optional[zio.aws.sagemaker.model.MonitoringStoppingCondition.ReadOnly]
    def getJobDefinitionArn: ZIO[Any, Nothing, MonitoringJobDefinitionArn] =
      ZIO.succeed(jobDefinitionArn)
    def getJobDefinitionName: ZIO[Any, Nothing, MonitoringJobDefinitionName] =
      ZIO.succeed(jobDefinitionName)
    def getCreationTime: ZIO[Any, Nothing, Timestamp] =
      ZIO.succeed(creationTime)
    def getModelBiasBaselineConfig: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.ModelBiasBaselineConfig.ReadOnly
    ] = AwsError.unwrapOptionField(
      "modelBiasBaselineConfig",
      modelBiasBaselineConfig
    )
    def getModelBiasAppSpecification: ZIO[
      Any,
      Nothing,
      zio.aws.sagemaker.model.ModelBiasAppSpecification.ReadOnly
    ] = ZIO.succeed(modelBiasAppSpecification)
    def getModelBiasJobInput: ZIO[
      Any,
      Nothing,
      zio.aws.sagemaker.model.ModelBiasJobInput.ReadOnly
    ] = ZIO.succeed(modelBiasJobInput)
    def getModelBiasJobOutputConfig: ZIO[
      Any,
      Nothing,
      zio.aws.sagemaker.model.MonitoringOutputConfig.ReadOnly
    ] = ZIO.succeed(modelBiasJobOutputConfig)
    def getJobResources: ZIO[
      Any,
      Nothing,
      zio.aws.sagemaker.model.MonitoringResources.ReadOnly
    ] = ZIO.succeed(jobResources)
    def getNetworkConfig: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.MonitoringNetworkConfig.ReadOnly
    ] = AwsError.unwrapOptionField("networkConfig", networkConfig)
    def getRoleArn: ZIO[Any, Nothing, RoleArn] = ZIO.succeed(roleArn)
    def getStoppingCondition: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.MonitoringStoppingCondition.ReadOnly
    ] = AwsError.unwrapOptionField("stoppingCondition", stoppingCondition)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.DescribeModelBiasJobDefinitionResponse
  ) extends zio.aws.sagemaker.model.DescribeModelBiasJobDefinitionResponse.ReadOnly {
    override val jobDefinitionArn: MonitoringJobDefinitionArn =
      zio.aws.sagemaker.model.primitives
        .MonitoringJobDefinitionArn(impl.jobDefinitionArn())
    override val jobDefinitionName: MonitoringJobDefinitionName =
      zio.aws.sagemaker.model.primitives
        .MonitoringJobDefinitionName(impl.jobDefinitionName())
    override val creationTime: Timestamp =
      zio.aws.sagemaker.model.primitives.Timestamp(impl.creationTime())
    override val modelBiasBaselineConfig
        : Optional[zio.aws.sagemaker.model.ModelBiasBaselineConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.modelBiasBaselineConfig())
        .map(value =>
          zio.aws.sagemaker.model.ModelBiasBaselineConfig.wrap(value)
        )
    override val modelBiasAppSpecification
        : zio.aws.sagemaker.model.ModelBiasAppSpecification.ReadOnly =
      zio.aws.sagemaker.model.ModelBiasAppSpecification
        .wrap(impl.modelBiasAppSpecification())
    override val modelBiasJobInput
        : zio.aws.sagemaker.model.ModelBiasJobInput.ReadOnly =
      zio.aws.sagemaker.model.ModelBiasJobInput.wrap(impl.modelBiasJobInput())
    override val modelBiasJobOutputConfig
        : zio.aws.sagemaker.model.MonitoringOutputConfig.ReadOnly =
      zio.aws.sagemaker.model.MonitoringOutputConfig
        .wrap(impl.modelBiasJobOutputConfig())
    override val jobResources
        : zio.aws.sagemaker.model.MonitoringResources.ReadOnly =
      zio.aws.sagemaker.model.MonitoringResources.wrap(impl.jobResources())
    override val networkConfig
        : Optional[zio.aws.sagemaker.model.MonitoringNetworkConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.networkConfig())
        .map(value =>
          zio.aws.sagemaker.model.MonitoringNetworkConfig.wrap(value)
        )
    override val roleArn: RoleArn =
      zio.aws.sagemaker.model.primitives.RoleArn(impl.roleArn())
    override val stoppingCondition: Optional[
      zio.aws.sagemaker.model.MonitoringStoppingCondition.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.stoppingCondition())
      .map(value =>
        zio.aws.sagemaker.model.MonitoringStoppingCondition.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.DescribeModelBiasJobDefinitionResponse
  ): zio.aws.sagemaker.model.DescribeModelBiasJobDefinitionResponse.ReadOnly =
    new Wrapper(impl)
}
